{% extends "tinyforum/base.html" %}

{% load fineforms i18n static %}

{% block extra-body-class %}forum{% endblock %}

{% block lead-title %}
<h1>{% trans "Edit post" %}</h1>
{% endblock %}

{% block main-region %}

<div class="row">
  <div class="small-11 medium-10 large-9 small-centered columns forum-form">
    <div class="row">
      <div class="columns small-11 medium-10 small-centered">


        {% if moderation %}<h2>Moderation</h2>{% endif %}

        <form method="post">
          {% csrf_token %}
          <script src="{% static 'webapp/lib/emojione.min.js' %}"></script>
          <script>CKEDITOR_BASEPATH='{% static "ckeditor/ckeditor/" %}';</script>
          {{ form.media }}
          {% ff_errors form %}
          <span class="show-for-sr">{{ form.text.label_tag }}</span>
          {% ff_field form.text type='field-plain' %}
          {{ form.text.errors }}

          {% ff_fields form exclude='text' %}

          <button type="submit">{% trans 'Submit' %}</button>
        </form>
      </div>
    </div>
  </div>
</div>

{% endblock %}
